/**
 * Open SUIT - Simple User Interface Toolkit
 * 
 * Copyright (c) 2009 France Telecom, http://www.francetelecom.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.ow2.opensuit.xml.base.html.table;

import java.io.PrintWriter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.ow2.opensuit.core.table.ITableRenderingContext;
import org.ow2.opensuit.core.util.BaseMessages;
import org.ow2.opensuit.core.util.HtmlUtils;
import org.ow2.opensuit.xml.base.html.table.TableRenderingContext.ColumnDef;
import org.ow2.opensuit.xml.interfaces.ILinkHrefRenderer;
import org.ow2.opensuit.xmlmap.annotations.XmlAncestor;
import org.ow2.opensuit.xmlmap.annotations.XmlAttribute;
import org.ow2.opensuit.xmlmap.annotations.XmlDoc;
import org.ow2.opensuit.xmlmap.annotations.XmlElement;
import org.ow2.opensuit.xmlmap.interfaces.IInitializable;
import org.ow2.opensuit.xmlmap.interfaces.IInitializationSupport;



@XmlDoc("A filter base on text input. Filters in the table view all rowswhose column contains the entered text.")
@XmlElement
public class TextFilter implements IFilter, IInitializable
{
	@XmlAncestor
	private Table table;
	
	@XmlAncestor
	private IColumnsProvider iColumn;
	
	@XmlDoc("Sets whether the filter is case unsensitive. Default: <code>true</code>.")
	@XmlAttribute(name="IgnoreCase", required=false)
	private boolean ignoreCase= true;
	
	public void initialize(IInitializationSupport initSupport, Object additionalSupport)
	{
	}
	public Object compileFilter(HttpServletRequest iRequest, String iFilter) throws Exception
	{
		if(iFilter == null)
			return null;
		iFilter = iFilter.trim();
		if(iFilter.length() == 0)
			return null;
		if(ignoreCase)
			return iFilter.toLowerCase();
		return iFilter;
	}
	public boolean passFilter(HttpServletRequest iRequest, Object iCompiledFilter, ColumnDef column, Object iRowObject) throws Exception
	{
		String filter = (String)iCompiledFilter;
		/* not useful
		if(filter == null || filter.length() == 0)
			return true;
		*/
		
		Object oText = iColumn.getCellDisplayedContent(iRequest, column, iRowObject);
		if(oText == null)
			return false;// ???
		String cellText = String.valueOf(oText);
		if(ignoreCase)
			return cellText.toLowerCase().indexOf(filter) >= 0;
		
		return cellText.indexOf(filter) >= 0;
	}
	public void render(HttpServletRequest iRequest, HttpServletResponse iResponse, ITableRenderingContext context, ILinkHrefRenderer iLinkRenderer, int icol) throws Exception
	{
		String currentFilter = context.getFilter(icol);
		if(currentFilter == null)
			currentFilter = "";
		
		PrintWriter iWriter = iResponse.getWriter();
		// --- render input text field
		iWriter.print("<input type='text'");
		iWriter.print(" name='");
		iWriter.print(table.getId()+".filter."+icol);
		iWriter.print("'");
		/*
		iWriter.print(" size='");
		iWriter.print(String.valueOf(10));
		iWriter.print("'");
		*/
		iWriter.print(" onkeypress='TextFilter_sumbitOnReturn(event)'");
		iWriter.print(" value=\"");
		iWriter.print(HtmlUtils.encode2HTML(currentFilter));
		iWriter.print("\"");
		iWriter.print(">");
		
		// --- render clear button
		String clearText = BaseMessages.getMessage(iResponse.getLocale(), "table.filter.clear");
		iWriter.print("<a class=clear");
		iWriter.print(" href='javascript:void(0)'");
		iWriter.print(" onclick=\"");
		iWriter.print("TextFilter_clear('"+table.getFormName()+"', '"+table.getId()+".filter."+icol+"'); return false;");
		iWriter.print("\"");
		iWriter.print(" title=\"");
		iWriter.print(HtmlUtils.encode2HTML(clearText));
		iWriter.print("\"");
		iWriter.print(">");
		iWriter.print(HtmlUtils.encode2HTML(clearText));
		iWriter.print("</a>");
	}
}
